aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--lib/private/ServerContainer.php6
1 files changed, 4 insertions, 2 deletions
diff --git a/lib/private/ServerContainer.php b/lib/private/ServerContainer.php
index a8583bd6875..daa480a75d1 100644
--- a/lib/private/ServerContainer.php
+++ b/lib/private/ServerContainer.php
@@ -154,8 +154,10 @@ class ServerContainer extends SimpleContainer {
try {
return $appContainer->queryNoFallback($name);
} catch (QueryException $e) {
- // Didn't find the service or the respective app container,
- // ignore it and fall back to the core container.
+ // Didn't find the service or the respective app container
+ // In this case the service won't be part of the core container,
+ // so we can throw directly
+ throw $e;
}
} elseif (str_starts_with($name, 'OC\\Settings\\') && substr_count($name, '\\') >= 3) {
$segments = explode('\\', $name);